summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kforecastview.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kforecastview.cpp')
-rw-r--r--kmymoney2/views/kforecastview.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kmymoney2/views/kforecastview.cpp b/kmymoney2/views/kforecastview.cpp
index 790c51b..d636ec4 100644
--- a/kmymoney2/views/kforecastview.cpp
+++ b/kmymoney2/views/kforecastview.cpp
@@ -46,8 +46,8 @@
#include "../reports/pivottable.h"
#include "../reports/pivotgrid.h"
-KForecastView::KForecastView(TQWidget *tqparent, const char *name) :
- KForecastViewDecl(tqparent,name)
+KForecastView::KForecastView(TQWidget *parent, const char *name) :
+ KForecastViewDecl(parent,name)
{
for(int i=0; i < MaxViewTabs; ++i)
m_needReload[i] = false;
@@ -605,7 +605,7 @@ void KForecastView::loadAccounts(MyMoneyForecast& forecast, const MyMoneyAccount
TQStringList::ConstIterator accList_t;
for(accList_t = accList.begin(); accList_t != accList.end(); ++accList_t ) {
MyMoneyAccount subAccount = file->account(*accList_t);
//only add the account if it is a forecast account or the tqparent of a forecast account
if(includeAccount(forecast, subAccount)) {
nameIdx[subAccount.id()] = subAccount.id();
}
@@ -605,7 +605,7 @@ void KForecastView::loadAccounts(MyMoneyForecast& forecast, const MyMoneyAccount
for(accList_t = accList.begin(); accList_t != accList.end(); ++accList_t ) {
MyMoneyAccount subAccount = file->account(*accList_t);
- //only add the account if it is a forecast account or the tqparent of a forecast account
+ //only add the account if it is a forecast account or the parent of a forecast account
if(includeAccount(forecast, subAccount)) {
nameIdx[subAccount.id()] = subAccount.id();